@@ -87,8 +87,8 @@ use Exporter qw( import );
 our @EXPORT = qw( 
     initialize_regression_test $faux_context
     req dbi_err docu_check 
-    create_testing_employee create_active_employee create_inactive_employee
-    delete_testing_employee delete_employee_by_nick
+    create_bare_employee create_active_employee create_inactive_employee
+    delete_bare_employee delete_employee_by_nick
     create_testing_activity delete_testing_activity
     create_testing_interval delete_testing_interval
     create_testing_component delete_testing_component
@@ -359,13 +359,18 @@ sub docu_check {
 }
 
 
-=head2 create_testing_employee
+=head2 create_bare_employee
 
-Tests will need to set up and tear down testing employees
+For use in tests only. Spawns an employee object and inserts it into the
+database.
+
+Takes PROPLIST which is passed through unmunged to the employee spawn method.
+
+Returns the new Employee object.
 
 =cut
 
-sub create_testing_employee {
+sub create_bare_employee {
     my ( $PROPS ) = validate_pos( @_,
         { type => HASHREF },
     );
@@ -373,82 +378,96 @@ sub create_testing_employee {
     hash_the_password( $PROPS );
 
     my $emp = App::Dochazka::REST::Model::Employee->spawn( $PROPS );
-    is( ref($emp), 'App::Dochazka::REST::Model::Employee', 'create_testing_employee 1' );
+    is( ref($emp), 'App::Dochazka::REST::Model::Employee', 'create_bare_employee 1' );
 
     my $status = $emp->insert( $faux_context );
     if ( $status->not_ok ) {
+        diag( "Employee insert method returned NOT_OK status in create_bare_employee" );
+        diag( "test automation function, which was called from " . (caller)[1] . " line " . (caller)[2] );
+        diag( "with arguments: " . Dumper( $PROPS ) );
+        diag( "Full status returned by employee insert method:" );
         diag( Dumper $status );
         BAIL_OUT(0);
     }
+    is( $status->level, "OK", 'create_bare_employee 2' );
+    my $employee_object = $status->payload;
+    is( ref( $employee_object ), 'App::Dochazka::REST::Model::Employee' );
 
-    is( $status->level, "OK", 'create_testing_employee 2' );
-    is( ref( $status->payload ), 'App::Dochazka::REST::Model::Employee' );
-    return $status->payload;
+    return $employee_object;
 }
 
 
-=head2 create_active_employee
+=head2 delete_bare_employee
 
-Create testing employee with 'active' privilege
+Takes a single argument: the EID.
+
+Loads the EID into a new Employee object and calls that object's delete method.
 
 =cut
 
-sub create_active_employee {
-    my ( $test ) = @_;
-    note('create active employee');
-    my $eid_of_active = create_testing_employee( { nick => 'active', password => 'active' } )->eid;
-    my $status = req( $test, 201, 'root', 'POST', "priv/history/eid/$eid_of_active", 
-        '{ "effective":"1892-01-01", "priv":"active" }' );
-    ok( $status->ok, "Create active employee 2" );
-    is( $status->code, 'DOCHAZKA_CUD_OK', "Create active employee 3" );
-    return $eid_of_active;
-}
-
-
-=head2 create_inactive_employee
-
-Create testing employee with 'active' privilege
-
-=cut
-
-sub create_inactive_employee {
-    my ( $test ) = @_;
-    note( 'create inactive employee' );
-    my $eid_of_inactive = create_testing_employee( { nick => 'inactive', password => 'inactive' } )->eid;
-    my $status = req( $test, 201, 'root', 'POST', "priv/history/eid/$eid_of_inactive", 
-        '{ "effective":"1892-01-01", "priv":"inactive" }' );
-    ok( $status->ok, "Create inactive employee 2" );
-    is( $status->code, 'DOCHAZKA_CUD_OK', "Create inactive employee 3" );
-    return $eid_of_inactive; 
-}
-
-
-=head2 delete_testing_employee
-
-Tests will need to set up and tear down testing employees (takes EID)
-
-=cut
-
-sub delete_testing_employee {
+sub delete_bare_employee {
     my $eid = shift;  
     note( "delete testing employee with EID $eid" );
     my $status = App::Dochazka::REST::Model::Employee->load_by_eid( $dbix_conn, $eid );
     if ( $status->not_ok ) {
+        diag( "Employee load_by_eid method returned NOT_OK status in delete_bare_employee" );
+        diag( "test automation function, which was called from " . (caller)[1] . " line " . (caller)[2] );
+        diag( "with EID $eid" );
+        diag( "Full status returned by Employee load_by_eid method:" );
         diag( Dumper $status );
         BAIL_OUT(0);
     }
-    is( $status->level, 'OK', 'delete_testing_employee 1' );
+    is( $status->level, 'OK', 'delete_bare_employee 1' );
     my $emp = $status->payload;
     $status = $emp->delete( $faux_context );
     if ( $status->not_ok ) {
         diag( Dumper $status );
         BAIL_OUT(0);
     }
-    is( $status->level, 'OK', 'delete_testing_employee 2' );
+    is( $status->level, 'OK', 'delete_bare_employee 2' );
     return;
 }
 
 
+sub _create_employee {
+    my ( $test, $privspec ) = @_;
+
+    note("create $privspec employee");
+    my $eid = create_bare_employee( { nick => $privspec, password => $privspec } )->eid;
+    my $status = req( $test, 201, 'root', 'POST', "priv/history/eid/$eid", 
+        "{ \"effective\":\"1892-01-01\", \"priv\":\"$privspec\" }" );
+    ok( $status->ok, "Create $privspec employee 2" );
+    is( $status->code, 'DOCHAZKA_CUD_OK', "Create $privspec employee 3" );
+    return $eid;
+
+}
+
+=head2 create_active_employee
+
+Create a testing employee with 'active' privilege. The employee will get an
+'active' privhistory record with date 1892-01-01.
+
+=cut
+
+sub create_active_employee {
+    my ( $test ) = @_;
+    return _create_employee( $test, "active" );
+}
+
+
+=head2 create_inactive_employee
+
+Create a testing employee with 'inactive' privilege. The employee will get an
+'inactive' privhistory record with date 1892-01-01.
+
+=cut
+
+sub create_inactive_employee {
+    my ( $test ) = @_;
+    return _create_employee( $test, "inactive" );
+}
+
+
 =head2 delete_employee_by_nick
 
 Delete testing employee (takes Plack::Test object and nick)
@@ -893,6 +912,7 @@ sub gen_activity {
     BAIL_OUT(0);
 }
 
+
 sub gen_employee {
     my $dis = shift;
     my $nick = 'bubbaTheCat';
@@ -927,17 +947,41 @@ sub gen_employee {
     BAIL_OUT(0);
 }
 
+
 sub gen_interval {
     my $dis = shift;
+    my $eid = $site->DOCHAZKA_EID_OF_ROOT;
+    my $aid = App::Dochazka::REST::Model::Activity->load_by_code( $dbix_conn, 'WORK' )->aid;
     if ( $dis eq 'create' ) {
 
+        # create an interval
+        my $int = App::Dochazka::REST::Model::Interval->spawn(
+            eid => $eid,
+            aid => $aid,
+            intvl => "['1950-06-30 09:00', '1950-06-30 10:00')",
+        );
+        my $status = $int->insert( $faux_context );
+        is( $status->level, 'OK' );
+        $int = $status->payload;
+        is( $int->eid, $eid );
+        is( $int->aid, $aid );
+        ok( $int->iid > 0 );
+        # FIXME: use "state" variable to store iid for use in retrieve
+        return $int;
+
     } elsif ( $dis eq 'retrieve' ) {
 
+#        my $status = App::Dochazka::REST::Model::Interval->load_by_iid( $dbix_conn, $iid );
+#        return $status;
+
+    } elsif ( $dis eq 'delete' ) {
+
     }
     diag( "gen_interval: AAAAAAHHHHH@@@!! \$dis " . Dumper( $dis ) );
     BAIL_OUT(0);
 }
 
+
 sub gen_lock {
     my $dis = shift;
     if ( $dis eq 'create' ) {
@@ -951,6 +995,7 @@ sub gen_lock {
     BAIL_OUT(0);
 }
 
+
 sub gen_privhistory {
     my $dis = shift;
     if ( $dis eq 'create' ) {
